Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1799)

Unified Diff: content/browser/ssl/ssl_manager.h

Issue 9406001: Factor out ResourceDispatcherHost dependent code around SSLManager (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase for retry Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/ssl/ssl_error_handler.cc ('k') | content/browser/ssl/ssl_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/ssl/ssl_manager.h
diff --git a/content/browser/ssl/ssl_manager.h b/content/browser/ssl/ssl_manager.h
index db2b65dbe6484adbfc005e3ffb79456dbf3515e0..668c3e09e28daecfdc2f9d4931e3cfa6791c0546 100644
--- a/content/browser/ssl/ssl_manager.h
+++ b/content/browser/ssl/ssl_manager.h
@@ -11,7 +11,9 @@
#include "base/basictypes.h"
#include "base/memory/scoped_ptr.h"
#include "content/browser/ssl/ssl_policy_backend.h"
+#include "content/browser/ssl/ssl_error_handler.h"
#include "content/common/content_export.h"
+#include "content/public/browser/global_request_id.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
#include "googleurl/src/gurl.h"
@@ -30,7 +32,6 @@ class NavigationEntryImpl;
namespace net {
class SSLInfo;
-class URLRequest;
} // namespace net
// The SSLManager SSLManager controls the SSL UI elements in a TabContents. It
@@ -45,11 +46,16 @@ class SSLManager : public content::NotificationObserver {
public:
// Entry point for SSLCertificateErrors. This function begins the process
// of resolving a certificate error during an SSL connection. SSLManager
// will adjust the security UI and either call |Cancel| or
// |ContinueDespiteLastError| on the net::URLRequest.
//
// Called on the IO thread.
- static void OnSSLCertificateError(net::URLRequest* request,
+ static void OnSSLCertificateError(SSLErrorHandler::Delegate* delegate,
+ const content::GlobalRequestID& id,
+ ResourceType::Type resource_type,
+ const GURL& url,
+ int render_process_id,
+ int render_view_id,
const net::SSLInfo& ssl_info,
bool fatal);
« no previous file with comments | « content/browser/ssl/ssl_error_handler.cc ('k') | content/browser/ssl/ssl_manager.cc » ('j') | no next file with comments »
@@ -45,11 +46,16 @@ class SSLManager : public content::NotificationObserver {
// Entry point for SSLCertificateErrors. This function begins the process
// of resolving a certificate error during an SSL connection. SSLManager
- // will adjust the security UI and either call |Cancel| or
- // |ContinueDespiteLastError| on the net::URLRequest.
+ // will adjust the security UI and either call |CancelSSLRequest| or
+ // |ContinueSSLRequest| of |delegate| with |id| as the first argument.
//
// Called on the IO thread.

Powered by Google App Engine
This is Rietveld 408576698